==> blanco.plugin.dbdotnet_0.4.6-src.zip: blancoDbDotNetPlugin/blanco/main/blanco/plugin/dbdotnet/resourcebundle/BlancoDbDotNetPluginResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.plugin.dbdotnet.resourcebundle;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoDbDotNetPlugin]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 * m̃P[<BR>
 * <UL>
 * <LI>ja
 * </UL>
 */
public class BlancoDbDotNetPluginResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoDbDotNetPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbDotNetPlugin]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoDbDotNetPluginResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoDbDotNetPlugin");
        } catch (MissingResourceException ex) {
            final String message = "ꖼ[BlancoDbDotNetPlugin]AftHg̃P[AĂяõNX[_gpāA\[Xoh̎擾݂܂s܂B`̐ݒl𗘗pďs܂B:" + ex.toString();
            System.out.println(message);
        }
    }

    /**
     * BlancoDbDotNetPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbDotNetPlugin]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoDbDotNetPluginResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoDbDotNetPlugin", locale);
        } catch (MissingResourceException ex) {
            final String message = "ꖼ[BlancoDbDotNetPlugin]AP[[" + locale.toString() + "]AĂяõNX[_gpāA\[Xoh̎擾݂܂s܂B`̐ݒl𗘗pďs܂B:" + ex.toString();
            System.out.println(message);
        }
    }

    /**
     * BlancoDbDotNetPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbDotNetPlugin]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoDbDotNetPluginResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoDbDotNetPlugin", locale, loader);
        } catch (MissingResourceException ex) {
            final String message = "ꖼ[BlancoDbDotNetPlugin]AP[[" + locale.toString() + "]Aw̃NX[_gpāA\[Xoh̎擾݂܂s܂B`̐ݒl𗘗pďs܂B:" + ex.toString();
            System.out.println(message);
        }
    }

    /**
     * bundle[BlancoDbDotNetPlugin], key[CLEAR_TMP_FOLDER]
     *
     * [true] (ja)<br>
     *
     * @return key[CLEAR_TMP_FOLDER]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getClearTmpFolder() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "true";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CLEAR_TMP_FOLDER");
            }
        } catch (MissingResourceException ex) {
            final String message = "ꖼ[BlancoDbDotNetPlugin]AL[[CLEAR_TMP_FOLDER]̒`擾ł܂łB`̒l𗘗pďs܂B:" + ex.toString();
            System.out.println(message);
        }
        // u͂ЂƂ܂B
        return strFormat;
    }
}

==> blanco.plugin.dbdotnet_0.5.5-src.zip: blancoDbDotNetPlugin/blanco/main/blanco/plugin/dbdotnet/resourcebundle/BlancoDbDotNetPluginResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.plugin.dbdotnet.resourcebundle;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoDbDotNetPlugin]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 * m̃P[<BR>
 * <UL>
 * <LI>ja
 * </UL>
 */
public class BlancoDbDotNetPluginResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoDbDotNetPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbDotNetPlugin]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoDbDotNetPluginResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoDbDotNetPlugin");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoDbDotNetPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbDotNetPlugin]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoDbDotNetPluginResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoDbDotNetPlugin", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoDbDotNetPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbDotNetPlugin]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoDbDotNetPluginResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoDbDotNetPlugin", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoDbDotNetPlugin], key[CLEAR_TMP_FOLDER]
     *
     * [true] (ja)<br>
     *
     * @return key[CLEAR_TMP_FOLDER]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getClearTmpFolder() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "true";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CLEAR_TMP_FOLDER");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }
}
